@@ -4,9 +4,12 @@
 # Usage: basic.sh <release> <build_system> <config> <job_type>
 set -eux
 
+: ${OPT_ADDITIONAL_PARAMETERS:=""}
+
 # CONFIG and JOB_TYPE are not used here, but kept for
 # consistency with other jobs to make JJB cleaner.
 RELEASE=$1
+# unused variable in script, kept for consistency
 BUILD_SYS=$2
 CONFIG=$3
 JOB_TYPE=$4
@@ -17,8 +20,18 @@ JOB_TYPE=$4
 socketdir=$(mktemp -d /tmp/sockXXXXXX)
 export ANSIBLE_SSH_CONTROL_PATH=$socketdir/%%h-%%r
 
-bash $WORKSPACE/tripleo-quickstart/quickstart.sh \
+# preparation steps to run with the gated roles
+CI_SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
+source $CI_SCRIPT_DIR/include-gate-changes.sh
+
+# CI_ENV is set on the slave running the jobs
+# REL_TYPE can be specific release type like 'testing'
+
+bash quickstart.sh \
+    --playbook quickstart.yml \
     --working-dir $WORKSPACE/ \
     --no-clone \
-    --release $RELEASE \
+    --bootstrap \
+    --release ${CI_ENV:+$CI_ENV/}$RELEASE${REL_TYPE:+-$REL_TYPE} \
     $VIRTHOST
+
