@@ -16,26 +16,16 @@ export ANSIBLE_SSH_CONTROL_PATH=$socketdir/%%h-%%r
 
 pushd $WORKSPACE/tripleo-quickstart
 
-bash $WORKSPACE/tripleo-quickstart/quickstart.sh \
+bash quickstart.sh \
+    --bootstrap \
     --tags all \
     --config $WORKSPACE/config/general_config/$CONFIG.yml \
     --working-dir $WORKSPACE/ \
     --no-clone \
-    --extra-vars @$WORKSPACE/config/general_config/devmode.yml \
-    --release "${RELEASE}-tripleo" \
+    --release master-tripleo-ci \
     --extra-vars test_ping=False \
-    $VIRTHOST
-
-bash $WORKSPACE/tripleo-quickstart/quickstart.sh \
-    --tags all \
-    --working-dir $WORKSPACE/ \
-    --no-clone \
-    --bootstrap \
-    --retain-inventory \
-    --requirements $WORKSPACE/tripleo-quickstart/quickstart-role-requirements.txt \
-    --playbook tempest.yml \
-    --extra-vars tempest_source=rdo \
-    --extra-vars tempest_format=venv \
+    --extra-vars run_tempest=True  \
     $VIRTHOST
 
 popd
+
