@@ -13,12 +13,11 @@ MAJOR_UPGRADE=$6
 PACEMAKER=$7
 TARGET_VERSION=$8
 
-SKIP_TAGS="undercloud-post-install"
 
 if [ "$JOB_TYPE" = "gate" ] || [ "$JOB_TYPE" = "periodic" ]; then
-    LOCATION='stable'
+    unset REL_TYPE
 elif [ "$JOB_TYPE" = "promote" ]; then
-    LOCATION='testing'
+    REL_TYPE=$LOCATION
 else
     echo "Job type must be one of gate, periodic, or promote"
     exit 1
@@ -30,22 +29,19 @@ fi
 socketdir=$(mktemp -d /tmp/sockXXXXXX)
 export ANSIBLE_SSH_CONTROL_PATH=$socketdir/%%h-%%r
 
-pushd $WORKSPACE/tripleo-quickstart
 bash quickstart.sh \
-    -e undercloud_image_url="http://artifacts.ci.centos.org/artifacts/rdo/images/$RELEASE/$BUILD_SYS/$LOCATION/undercloud.qcow2" \
     --config $WORKSPACE/config/general_config/$CONFIG.yml \
     --extra-vars upgrade_delorean_hash=$DELOREAN_HASH \
     --extra-vars major_upgrade=$MAJOR_UPGRADE \
     --extra-vars enable_pacemaker=$PACEMAKER \
     --extra-vars target_upgrade_version=$TARGET_VERSION \
+    --extra-vars set_overcloud_workers=false \
     --working-dir $WORKSPACE/ \
-    --skip-tags $SKIP_TAGS \
     --no-clone \
     --bootstrap \
     --tags all \
     --teardown all \
-    --requirements $WORKSPACE/tripleo-quickstart/quickstart-role-requirements.txt \
     --playbook upgrade.yml \
-    --release $RELEASE \
+    --release ${CI_ENV:+$CI_ENV/}$RELEASE${REL_TYPE:+-$REL_TYPE} \
     $VIRTHOST
-popd
+
